@@ -1,3 +1,4 @@
+# -*- coding: utf-8 -*-
 # ProDy: A Python Package for Protein Dynamics Analysis
 # 
 # Copyright (C) 2010-2012 Ahmet Bakan
@@ -21,7 +22,9 @@ __author__ = 'Ahmet Bakan'
 __copyright__ = 'Copyright (C) 2010-2012 Ahmet Bakan'
 
 import numpy as np
-from prody import Atomic, AtomGroup
+
+from prody import LOGGER
+from prody.atomic import Atomic, AtomGroup
 from prody.measure import getRMSD
 from prody.tools import checkCoords, importLA
 
@@ -29,9 +32,6 @@ from conformation import *
 
 __all__ = ['Ensemble']
 
-pkg = __import__(__package__) 
-LOGGER = pkg.LOGGER
-
 class Ensemble(object):
     
     """A class for analysis of arbitrary conformational ensembles. 
@@ -61,7 +61,6 @@ class Ensemble(object):
         if isinstance(title, (Atomic, Ensemble)):
             self.setCoords(title.getCoords())
             self.addCoordset(title)
-
     
     def __repr__(self):
     
@@ -289,18 +288,18 @@ class Ensemble(object):
 
         return self._n_csets
 
-    def addCoordset(self, coords, allcoordsets=True):
-        """Add coordinate set(s) as conformation(s).  :class:`~.Atomic` 
-        instances are accepted as *coords* argument.  If *allcoordsets* is 
+    def addCoordset(self, coords, allcests=True):
+        """Add coordinate set(s) as to the ensemble.  :class:`~.Atomic` 
+        instances are accepted as *coords* argument.  If *allcests* is 
         ``True``, all coordinate sets from the :class:`~.Atomic` instance 
         will be appended to the ensemble.  Otherwise, only the active 
         coordinate set will be appended."""
         
-        assert isinstance(allcoordsets, bool), 'allcoordsets must be boolean'
+        assert isinstance(allcests, bool), 'allcests must be boolean'
         if not isinstance(coords, np.ndarray):
             if isinstance(coords, (Atomic, Ensemble)):
                 atoms = coords
-                if allcoordsets:
+                if allcests:
                     coords = atoms.getCoordsets()
                 else:
                     coords = atoms.getCoords()
@@ -421,16 +420,14 @@ class Ensemble(object):
         """Superpose the ensemble onto the reference coordinates."""
         
         if self._coords is None:
-            raise AttributeError('coordinates are not set, use `setCoords`')
+            raise ValueError('coordinates are not set, use `setCoords`')
         if self._confs is None or len(self._confs) == 0: 
-            raise AttributeError('conformations are not set, use `addCoordset`'
-                                )
-        LOGGER.info('Superposing structures:')
+            raise ValueError('conformations are not set, use `addCoordset`')
         LOGGER.timeit()
-        self._superpose()
-        LOGGER.timing('Superposition is completed in %.2f seconds.')
+        self._superpose(trans=True) # trans kwarg is used by PDBEnsemble
+        LOGGER.timing('Superposition completed in %.2f seconds.')
         
-    def _superpose(self):
+    def _superpose(self, **kwargs):
         """Superpose conformations and update coordinates."""
         
         indices = self._indices
@@ -495,20 +492,19 @@ class Ensemble(object):
         LOGGER.clear()
             
     def iterpose(self, rmsd=0.0001):
-        """Iteratively superpose the ensemble until convergence.
+        """Iteratively superpose the ensemble until convergence.  Initially, 
+        all conformations are aligned with the reference coordinates.  Then 
+        mean coordinates are calculated, and are set as the new reference 
+        coordinates.  This is repeated until reference coordinates do not 
+        change.  This is determined by the value of RMSD between the new and 
+        old reference coordinates.        
         
-        Initially, all conformations are aligned with the reference 
-        coordinates. Then mean coordinates are calculated, and are set
-        as the new reference coordinates. This is repeated until 
-        reference coordinates do not change. This is determined by
-        the value of RMSD between the new and old reference coordinates.        
-        
-        :arg rmsd: RMSD (A) between old and new reference coordinates 
-                     to converge
-        :type rmsd: float, default is 0.0001"""
+        :arg rmsd: change in reference coordinates to determine convergence,
+            default is 0.0001 Å RMSD
+        :type rmsd: float"""
         
         if self._coords is None:
-            raise AttributeError('coordinates are not set, use `setCoord`')
+            raise AttributeError('coordinates are not set, use `setCoords`')
         if self._confs is None or len(self._confs) == 0: 
             raise AttributeError('conformations are not set, use `addCoordset`'
                                  )
@@ -534,9 +530,9 @@ class Ensemble(object):
         LOGGER.timing('Iterative superposition completed in %.2fs.')
 
     def getMSFs(self):
-        """Calculate and return mean square fluctuations (MSFs). 
-        Note that you might need to align the conformations using 
-        :meth:`superpose` or :meth:`iterpose` before calculating MSFs."""
+        """Calculate and return mean square fluctuations (MSFs).  Note that 
+        you may need to align the conformations using :meth:`superpose` or 
+        :meth:`iterpose` before calculating MSFs."""
         
         if self._confs is None: 
             return
@@ -554,14 +550,14 @@ class Ensemble(object):
         return ssqf.sum(1) / self._n_csets
     
     def getRMSFs(self):
-        """Calculate and return root mean square fluctuations (RMSFs). 
-        Note that you might need to align the conformations using 
+        """Calculate and return root mean square fluctuations (RMSFs).  
+        Note that you may need to align the conformations using 
         :meth:`superpose` or meth:`iterpose` before calculating RMSFs."""
 
         return self.getMSFs() ** 0.5
             
     def getDeviations(self):
-        """Return deviations from reference coordinates. Note that you
+        """Return deviations from reference coordinates.  Note that you
         might need to align the conformations using :meth:`superpose` or 
         :meth:`iterpose` before calculating deviations."""
         
@@ -575,9 +571,9 @@ class Ensemble(object):
         return self._getCoordsets() - self._coords 
         
     def getRMSDs(self):
-        """Calculate and return root mean square deviations (RMSDs). Note that 
-        you might need to align the conformations using :meth:`superpose` or 
-        :meth:`iterpose` before calculating RMSDs."""
+        """Calculate and return root mean square deviations (RMSDs).  Note 
+        that you might need to align the conformations using :meth:`superpose` 
+        or :meth:`iterpose` before calculating RMSDs."""
         
         if self._confs is None or self._coords is None: 
             return None
